==> xkaapi-2.1.tar.gz: xkaapi-2.1/src/machine/cuda/kaapi_cuda_dev.h <==
/*
 ** xkaapi
 **
 ** Copyright 2009,2010,2011,2012 INRIA.
 **
 ** Contributors :
 **
 ** thierry.gautier@inrialpes.fr
 ** Joao.Lima@imagf.r / joao.lima@inf.ufrgs.br
 **
 ** This software is a computer program whose purpose is to execute
 ** multithreaded computation with data flow synchronization between
 ** threads.
 **
 ** This software is governed by the CeCILL-C license under French law
 ** and abiding by the rules of distribution of free software.  You can
 ** use, modify and/ or redistribute the software under the terms of
 ** the CeCILL-C license as circulated by CEA, CNRS and INRIA at the
 ** following URL "http://www.cecill.info".
 **
 ** As a counterpart to the access to the source code and rights to
 ** copy, modify and redistribute granted by the license, users are
 ** provided only with a limited warranty and the software's author,
 ** the holder of the economic rights, and the successive licensors
 ** have only limited liability.
 **
 ** In this respect, the user's attention is drawn to the risks
 ** associated with loading, using, modifying and/or developing or
 ** reproducing the software by the user in light of its specific
 ** status of free software, that may mean that it is complicated to
 ** manipulate, and that also therefore means that it is reserved for
 ** developers and experienced professionals having in-depth computer
 ** knowledge. Users are therefore encouraged to load and test the
 ** software's suitability as regards their requirements in conditions
 ** enabling the security of their systems and/or data to be ensured
 ** and, more generally, to use and operate it in the same conditions
 ** as regards security.
 **
 ** The fact that you are presently reading this means that you have
 ** had knowledge of the CeCILL-C license and that you accept its
 ** terms.
 **
 */

#ifndef KAAPI_CUDA_DEV_H_INCLUDED
#define KAAPI_CUDA_DEV_H_INCLUDED

#include "kaapi_cuda_proc.h"

int kaapi_cuda_dev_open(kaapi_cuda_proc_t *, unsigned int);

void kaapi_cuda_dev_close(kaapi_cuda_proc_t *);

kaapi_processor_t *kaapi_cuda_mem_get_proc(void);

int kaapi_cuda_dev_enable_peer_access(kaapi_cuda_proc_t * const);

static inline int kaapi_cuda_dev_has_peer_access(unsigned int peer)
{
  kaapi_assert_debug((peer >= 0) && (peer < KAAPI_CUDA_MAX_DEV));
  return kaapi_processor_get_cudaproc(kaapi_get_current_processor())->peers[peer];
}

#endif				/* ! KAAPI_CUDA_DEV_H_INCLUDED */

==> xkaapi-2.2.tar.gz: xkaapi-2.2/src/machine/cuda/kaapi_cuda_dev.h <==
/*
 ** xkaapi
 **
 ** Copyright 2009,2010,2011,2012 INRIA.
 **
 ** Contributors :
 **
 ** thierry.gautier@inrialpes.fr
 ** Joao.Lima@imagf.r / joao.lima@inf.ufrgs.br
 **
 ** This software is a computer program whose purpose is to execute
 ** multithreaded computation with data flow synchronization between
 ** threads.
 **
 ** This software is governed by the CeCILL-C license under French law
 ** and abiding by the rules of distribution of free software.  You can
 ** use, modify and/ or redistribute the software under the terms of
 ** the CeCILL-C license as circulated by CEA, CNRS and INRIA at the
 ** following URL "http://www.cecill.info".
 **
 ** As a counterpart to the access to the source code and rights to
 ** copy, modify and redistribute granted by the license, users are
 ** provided only with a limited warranty and the software's author,
 ** the holder of the economic rights, and the successive licensors
 ** have only limited liability.
 **
 ** In this respect, the user's attention is drawn to the risks
 ** associated with loading, using, modifying and/or developing or
 ** reproducing the software by the user in light of its specific
 ** status of free software, that may mean that it is complicated to
 ** manipulate, and that also therefore means that it is reserved for
 ** developers and experienced professionals having in-depth computer
 ** knowledge. Users are therefore encouraged to load and test the
 ** software's suitability as regards their requirements in conditions
 ** enabling the security of their systems and/or data to be ensured
 ** and, more generally, to use and operate it in the same conditions
 ** as regards security.
 **
 ** The fact that you are presently reading this means that you have
 ** had knowledge of the CeCILL-C license and that you accept its
 ** terms.
 **
 */

#ifndef KAAPI_CUDA_DEV_H_INCLUDED
#define KAAPI_CUDA_DEV_H_INCLUDED

#include "kaapi_cuda_impl.h"

/* Open and initialize a CUDA device. This function does not initialize KAAPI structures.
 \param proc: CUDA processor structure.
 \param ctx: context index of current KAAPI CUDA context.
 \param dev: device ID to be open.
 \retval 0 in case of success, else an error code from CUDA runtime.
 */
int kaapi_cuda_dev_open(kaapi_cuda_ctx_t* const ctx);

void kaapi_cuda_dev_close(kaapi_cuda_proc_t *);

kaapi_processor_t *kaapi_cuda_mem_get_proc(void);

int kaapi_cuda_dev_enable_peer_access(kaapi_cuda_ctx_t* const ctx);

int kaapi_cuda_dev_has_peer_access(const int src, const int dest);

#endif				/* ! KAAPI_CUDA_DEV_H_INCLUDED */
